@@ -216,21 +216,21 @@ def init():
                     origin = repo.remote(name='origin')
                     res=origin.pull()
                     print("Looking for Pull Opeartion")
-                    time.sleep(10)
+                    time.sleep(60)
                     flag=flag+1
                     
                 else:
                     print("no files to pull")
-                    time.sleep(10)
+                    time.sleep(60)
                     flag=0
 
             curtime = datetime.datetime.now()
             response2 = requests.post('http://35.225.89.124/fetch_log',data={'project_id':project_id,'repo_name':repo_name,'Time ':curtime,'user_name':username})
            #success , project id , repo name , current date and time , email id'
-            if(flag>0):
-                print('Pull operation successfull')
-            else:
-                print("No files for pull found")
+            # if(flag>0):
+            #     print('Pull operation successfull')
+            # else:
+            #     print("No files for pull found")
             # print("status code is ",response2.status_code)
 
           
